@@ -1,8 +1,8 @@
 package Business::ID::KTP;
-our $VERSION = '0.02';
-# ABSTRACT: See Business::ID::NIK instead
-
-
+BEGIN {
+  $Business::ID::KTP::VERSION = '0.03';
+}
+use parent qw(Business::ID::NIK);
 1;
 
 __END__
@@ -10,23 +10,19 @@ __END__
 
 =head1 NAME
 
-Business::ID::KTP - See Business::ID::NIK instead
+Business::ID::KTP
 
 =head1 VERSION
 
-version 0.02
-
-=head1 SEE ALSO
-
-L<Business::ID::NIK>
+version 0.03
 
 =head1 AUTHOR
 
-  Steven Haryanto <stevenharyanto@gmail.com>
+Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Steven Haryanto.
+This software is copyright (c) 2011 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
